hepstats.hypotests.core package
===============================

.. automodule:: hepstats.hypotests.core
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.hypotests.core.basetest
   hepstats.hypotests.core.confidence_interval
   hepstats.hypotests.core.discovery
   hepstats.hypotests.core.upperlimit
